==> kmymoney-5.0.4.tar.xz: kmymoney-5.0.4/kmymoney/plugins/kbanking/kbanking.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "aquamaniac@users.sourceforge.net,ipwizard@users.sourceforge.net,christian-david@web.de",
                "Name": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[ca@valencia]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[ca]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[en_GB]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[es]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[fr]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[gl]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[it]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[nl]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[pl]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[pt]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[pt_BR]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[ru]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[sv]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[uk]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[x-test]": "xxMartin Preuss,Thomas Baumgart,Christian Dávidxx"
            }
        ],
        "Description": "Add HBCI/FinTs online banking to KMyMoney",
        "Description[ca@valencia]": "Afig la banca en línia HBCI/FinTs al KMyMoney",
        "Description[ca]": "Afegeix la banca en línia HBCI/FinTs al KMyMoney",
        "Description[en_GB]": "Add HBCI/FinTs online banking to KMyMoney",
        "Description[es]": "Añade banca en línea HBCI/FinTs a KMyMoney",
        "Description[fr]": "Ajoute des capacités de banque HBCI/FinTs en ligne à KMyMoney",
        "Description[gl]": "Engade banca por internet HBCI e FinTs a KMyMoney",
        "Description[it]": "Aggiungi servizi bancari HBCI/FinTs in linea a KMyMoney",
        "Description[ko]": "KMyMoney에 HBCI/FinT 온라인 뱅킹 추가",
        "Description[nl]": "Voegt HBCI/FinTs online bankieren toe aan KMyMoney",
        "Description[pl]": "Dodaje obsługę bankowości HBCI/FinTs w sieci do KMyMoney",
        "Description[pt]": "Adição da banca 'online' do HBCI/FinTs ao KMyMoney",
        "Description[pt_BR]": "Adiciona correspondente bancário do tipo HBCI/FinTs no KMyMoney",
        "Description[sv]": "Lägg till HBCI/FinTs Internetbank till KMyMoney",
        "Description[uk]": "Онлайн-банкінг HBCI/FinTs у KMyMoney",
        "Description[x-test]": "xxAdd HBCI/FinTs online banking to KMyMoneyxx",
        "EnabledByDefault": true,
        "Icon": "network-connect",
        "Id": "kbanking",
        "License": "GPL",
        "Name": "KBanking",
        "Name[ca@valencia]": "KBanking",
        "Name[ca]": "KBanking",
        "Name[cs]": "KBanking",
        "Name[en_GB]": "KBanking",
        "Name[es]": "KBanking",
        "Name[fr]": "KBanking",
        "Name[gl]": "KBanking",
        "Name[it]": "KBanking",
        "Name[nl]": "KBanking",
        "Name[pl]": "KBanking",
        "Name[pt]": "KBanking",
        "Name[pt_BR]": "KBanking",
        "Name[sk]": "KBanking",
        "Name[sv]": "Kbank",
        "Name[uk]": "KBanking",
        "Name[x-test]": "xxKBankingxx",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}

==> kmymoney_5.0.8.orig.tar.xz: kmymoney-5.0.8/kmymoney/plugins/kbanking/kbanking.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "aquamaniac@users.sourceforge.net,ipwizard@users.sourceforge.net,christian-david@web.de",
                "Name": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[ca@valencia]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[ca]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[de]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[en_GB]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[es]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[fr]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[gl]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[it]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[nl]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[pl]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[pt]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[pt_BR]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[ru]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[sk]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[sv]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[uk]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[x-test]": "xxMartin Preuss,Thomas Baumgart,Christian Dávidxx"
            }
        ],
        "Description": "Add HBCI/FinTs online banking to KMyMoney",
        "Description[ca@valencia]": "Afig la banca en línia HBCI/FinTs al KMyMoney",
        "Description[ca]": "Afegeix la banca en línia HBCI/FinTs al KMyMoney",
        "Description[en_GB]": "Add HBCI/FinTs online banking to KMyMoney",
        "Description[es]": "Añade banca en línea HBCI/FinTs a KMyMoney",
        "Description[fr]": "Ajoute des capacités de banque HBCI/FinTs en ligne à KMyMoney",
        "Description[gl]": "Engade banca por Internet HBCI e FinTs a KMyMoney",
        "Description[it]": "Aggiungi servizi bancari HBCI/FinTs in linea a KMyMoney",
        "Description[ko]": "KMyMoney에 HBCI/FinT 온라인 뱅킹 추가",
        "Description[nl]": "Voegt HBCI/FinTs online bankieren toe aan KMyMoney",
        "Description[pl]": "Dodaje obsługę bankowości HBCI/FinTs w sieci do KMyMoney",
        "Description[pt]": "Adição da banca 'online' do HBCI/FinTs ao KMyMoney",
        "Description[pt_BR]": "Adiciona correspondente bancário do tipo HBCI/FinTs no KMyMoney",
        "Description[sk]": "Pridať HBCI/FinTs online banking do KMyMoney",
        "Description[sv]": "Lägg till HBCI/FinTs Internetbank till KMyMoney",
        "Description[uk]": "Онлайн-банкінг HBCI/FinTs у KMyMoney",
        "Description[x-test]": "xxAdd HBCI/FinTs online banking to KMyMoneyxx",
        "EnabledByDefault": true,
        "Icon": "network-connect",
        "Id": "kbanking",
        "License": "GPL",
        "Name": "KBanking",
        "Name[ca@valencia]": "KBanking",
        "Name[ca]": "KBanking",
        "Name[cs]": "KBanking",
        "Name[de]": "KBanking",
        "Name[en_GB]": "KBanking",
        "Name[es]": "KBanking",
        "Name[fr]": "KBanking",
        "Name[gl]": "KBanking",
        "Name[it]": "KBanking",
        "Name[nl]": "KBanking",
        "Name[pl]": "KBanking",
        "Name[pt]": "KBanking",
        "Name[pt_BR]": "KBanking",
        "Name[ru]": "KBanking",
        "Name[sk]": "KBanking",
        "Name[sv]": "Kbank",
        "Name[uk]": "KBanking",
        "Name[x-test]": "xxKBankingxx",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}
